@@ -29,12 +29,13 @@ d_boot <- function(dataset, i, p, type){
   return(quantile(dataset[i], p, type = type))
 }
 
-c_boot <- function(dataset, i, p, type){
+c_boot <- function(dataset, i, p, type, levels.met, levels.rep){
   data.b <- dataset[i, ]
 
   for (k in 1:((ncol(data.b)-1)/2)) {
     for (l in 1:((ncol(data.b)-1)/2)) {
-      dif <- data.b[, paste0("y_met1rep", k)] - data.b[, paste0("y_met2rep", l)]
+      dif <- data.b[, paste0("y.", levels.met[1], ".", levels.rep[k])] -
+        data.b[, paste0("y.", levels.met[2], ".", levels.rep[l])]
       if (k == 1 & l == 1) {
         d <- dif
       }
@@ -68,12 +69,13 @@ bca <- function(theta, conf.level = .95){
 
 
 TDI.Perez_Jaume_and_Carrasco <- function(data.wide, p, ub = TRUE, boot.type = c("Differences", "Cluster"),
-                                         alpha = 0.05, type = 8, R = 10000){
+                                         alpha = 0.05, type = 8, R = 10000, levels.met, levels.rep){
 
   if (ncol(data.wide) > 3) {
     for (k in 1:((ncol(data.wide)-1)/2)) {
       for (l in 1:((ncol(data.wide)-1)/2)) {
-        dif <- data.wide[, paste0("y_met1rep", k)] - data.wide[, paste0("y_met2rep", l)]
+        dif <- data.wide[, paste0("y.", levels.met[1], ".", levels.rep[k])] -
+          data.wide[, paste0("y.", levels.met[2], ".", levels.rep[l])]
         if (k == 1 & l == 1) {
           d <- dif
         } else{
@@ -82,7 +84,7 @@ TDI.Perez_Jaume_and_Carrasco <- function(data.wide, p, ub = TRUE, boot.type = c(
       }
     }
   } else{
-    d <- data.wide$y_met1 - data.wide$y_met2
+    d <- data.wide[, paste0("y.", levels.met[1])] - data.wide[, paste0("y.", levels.met[2])]
   }
 
   # tdi
@@ -121,7 +123,8 @@ TDI.Perez_Jaume_and_Carrasco <- function(data.wide, p, ub = TRUE, boot.type = c(
     }
     # cluster bootstrap
     if ("cluster" %in% boot.type) {
-      cb <- boot(data.wide, statistic = c_boot, R = R, stype = "i", p = p, type = type)
+      cb <- boot(data.wide, statistic = c_boot, R = R, stype = "i", p = p, type = type,
+                 levels.met = levels.met, levels.rep = levels.rep)
 
       tdi.c.boot <- cb$t
 
