@@ -88,10 +88,10 @@
 #'                           rater (and replicate number if it applies) from the original data frame provided.}
 #'   \item{\code{data.wide}}{an object of class \code{data.frame} with either:
 #'                           \itemize{
-#'                            \item{columns id, y_met1, y_met2 (in the case of no replicates) with the measurements of each method.}
-#'                            \item{columns id, y_met1rep1,..., y_met1rep\eqn{m}, y_met2rep1,..., y_met2rep\eqn{m}, with the measurements of each method and each replicate, where \eqn{m} is the number of replicates.}}
-#'                           Numbers 1 and 2 after met correspond to the first and second level of the column met in data, respectively.
-#'                           Numbers 1,..., \eqn{m} after rep correspond to the first,..., \eqn{m}-th level of the column rep in data, respectively.}
+#'                            \item{columns id, y.met1, y.met2 (in the case of no replicates) with the measurements of each method.}
+#'                            \item{columns id, y.met1.rep1,..., y.met1.rep\eqn{m}, y.met2.rep1,..., y.met2.rep\eqn{m}, with the measurements of each method and each replicate, where \eqn{m} is the number of replicates.}}
+#'                           met1 and met2 correspond to the names of the first and second level of the column met in data, respectively.
+#'                           While rep1,..., rep\eqn{m} correspond to the names of the first,..., \eqn{m}-th level of the column rep in data, respectively.}
 #' }
 #'
 #'
@@ -153,6 +153,8 @@
 #'
 #'    Perez‐Jaume, S., & Carrasco, J. L. (2015). A non‐parametric approach to estimate the total deviation index for non‐normal data. Statistics in Medicine, 34(25), 3318-3335.
 #'
+#' @importFrom furniture wide
+#'
 #' @export
 
 TDI <- function(data, y, id, met, rep = NA,
@@ -330,11 +332,11 @@ TDI <- function(data, y, id, met, rep = NA,
       }
     }
     data.long$z <- interaction(data.long$met, data.long$rep)
-    data.wide <- data.frame(id = unique(data.long$id))
-    for (j in 1:(nlevels(data.long$z)/2)){
-      data.wide[, paste0("y_met1rep", j)] <- data.long[data.long$z == levels(data.long$z)[2*j-1], "y"]
-      data.wide[, paste0("y_met2rep", j)] <- data.long[data.long$z == levels(data.long$z)[2*j], "y"]
-    }
+
+    data.wide <- wide(data.long[, c("y", "id", "z")],
+                      v.names = "y",
+                      timevar = "z",
+                      id = "id")
   } else{
     data.long <- data.frame(y = data[, y], id = data[, id], met = data[, met])
     if (!is.null(add.es)) {
@@ -342,9 +344,10 @@ TDI <- function(data, y, id, met, rep = NA,
         data.long[, add.es[i]] <- data[, add.es[i]]
       }
     }
-    y1 <- subset(data.long, met==levels(data.long[, "met"])[1])$y
-    y2 <- subset(data.long, met==levels(data.long[, "met"])[2])$y
-    data.wide <- data.frame(id=unique(data.long$id), y_met1 = y1, y_met2 = y2)
+    data.wide <- wide(data.long[, c("y", "id", "met")],
+                      v.names = "y",
+                      timevar = "met",
+                      id = "id")
   }
 
   # stop check NAs
@@ -405,8 +408,15 @@ TDI <- function(data, y, id, met, rep = NA,
 
     # method of Perez-Jaume and Carrasco
     if ("perez-jaume and carrasco" %in% method) {
+      if (m > 1){
+        levels.rep <- levels(data.long$rep)
+      } else{
+        levels.rep <- NULL
+      }
       pjc <- TDI.Perez_Jaume_and_Carrasco(data.wide, p = p[i], ub = ub, boot.type = boot.type,
-                                          alpha = alpha, type = type, R = R)
+                                          alpha = alpha, type = type, R = R,
+                                          levels.met = levels(data.long$met),
+                                          levels.rep = levels.rep)
       result$tdi.pc.np[i] <- pjc[1]
       result$ub_p_db.pc.np[i] <- pjc[2]
       result$ub_n_db.pc.np[i] <- pjc[3]
