@@ -286,16 +286,21 @@ plot.tdi <- function(x, tdi = FALSE, ub = FALSE, loa = FALSE, method = NULL,
 
   data <- x$data.wide
 
+  levels.met <- levels(x$data.long$met)
+
   nrep <- (ncol(data)-1)/2
 
   if(nrep == 1){
-    d <- data$y_met1 - data$y_met2
-    m <- (data$y_met1 + data$y_met2)/2
+    d <- data[, paste0("y.", levels.met[1])] - data[, paste0("y.", levels.met[2])]
+    m <- (data[, paste0("y.", levels.met[1])] + data[, paste0("y.", levels.met[2])])/2
   } else{
+    levels.rep <- levels(x$data.long$rep)
     for (k in 1:nrep) {
       for (l in 1:nrep) {
-        dif <- data[, paste0("y_met1rep", k)] - data[, paste0("y_met2rep", l)]
-        me <- (data[, paste0("y_met1rep", k)] + data[, paste0("y_met2rep", l)])/2
+        dif <- data[, paste0("y.", levels.met[1], ".", levels.rep[k])] -
+          data[, paste0("y.", levels.met[2], ".", levels.rep[l])]
+        me <- (data[, paste0("y.", levels.met[1], ".", levels.rep[k])] +
+                 data[, paste0("y.", levels.met[2], ".", levels.rep[l])])/2
         if(k == 1 & l == 1) {
           d <- dif
           m <- me
